c_material library
A library that provides a collection of material colors.
This library includes predefined colors to make it easier for developers to use consistent colors across their apps.
Classes
- CSemanticColors
- A centralized collection of semantic color tokens for the application.
- CTheme
- A utility class for generating consistent Material 3 themes.
- MaterialColors
- A class containing predefined material colors.